@@ -12,12 +12,24 @@ use vulkano::{
     device::{Device, Queue},
     image::{view::ImageView, ImmutableImage},
     pipeline::{
-        blend::{AttachmentBlend, BlendFactor, BlendOp},
-        depth_stencil::{CompareOp, DepthStencil},
-        vertex::BuffersDefinition,
-        viewport::Viewport,
-        GraphicsPipeline,
+        graphics::{
+            color_blend::{
+                AttachmentBlend,
+                BlendFactor,
+                BlendOp,
+                ColorBlendAttachmentState,
+                ColorBlendState,
+                ColorComponents,
+            },
+            depth_stencil::{CompareOp, DepthState, DepthStencilState},
+            input_assembly::{InputAssemblyState, PrimitiveTopology},
+            vertex_input::BuffersDefinition,
+            viewport::{Viewport, ViewportState},
+            GraphicsPipeline,
+        },
+        Pipeline,
         PipelineBindPoint,
+        StateMode,
     },
     render_pass::{RenderPass, Subpass},
     sampler::{Filter, MipmapMode, Sampler, SamplerAddressMode},
@@ -284,37 +296,43 @@ pub struct Renderer {
 }
 impl Renderer {
     pub fn new(render_pass: Arc<RenderPass>, device: Arc<Device>, queue: Arc<Queue>) -> Self {
-        let vs = vertex_shader::Shader::load(device.clone()).unwrap();
-        let fs = fragment_shader::Shader::load(device.clone()).unwrap();
+        let vs = vertex_shader::load(device.clone()).unwrap();
+        let fs = fragment_shader::load(device.clone()).unwrap();
 
-        let pipeline = Arc::new(
-            GraphicsPipeline::start()
-                .vertex_input(BuffersDefinition::new().vertex::<Vertex>())
-                .vertex_shader(vs.main_entry_point(), ())
-                .triangle_list()
-                .viewports_dynamic_scissors_irrelevant(1)
-                .fragment_shader(fs.main_entry_point(), ())
-                .blend_collective(AttachmentBlend {
-                    enabled: true,
-                    color_op: BlendOp::Add,
-                    color_source: BlendFactor::SrcAlpha,
-                    color_destination: BlendFactor::OneMinusSrcAlpha,
-                    alpha_op: BlendOp::Max,
-                    alpha_source: BlendFactor::One,
-                    alpha_destination: BlendFactor::One,
-                    mask_red: true,
-                    mask_green: true,
-                    mask_blue: true,
-                    mask_alpha: true,
-                })
-                .depth_stencil(DepthStencil {
-                    depth_compare: CompareOp::LessOrEqual,
-                    ..DepthStencil::simple_depth_test()
-                })
-                .render_pass(Subpass::from(render_pass, 0).unwrap())
-                .build(device.clone())
-                .unwrap(),
-        );
+        let pipeline = GraphicsPipeline::start()
+            .vertex_input_state(BuffersDefinition::new().vertex::<Vertex>())
+            .vertex_shader(vs.entry_point("main").unwrap(), ())
+            .input_assembly_state(
+                InputAssemblyState::new().topology(PrimitiveTopology::TriangleStrip),
+            )
+            .viewport_state(ViewportState::viewport_dynamic_scissor_irrelevant())
+            .fragment_shader(fs.entry_point("main").unwrap(), ())
+            .color_blend_state(ColorBlendState {
+                logic_op: None,
+                attachments: vec![ColorBlendAttachmentState {
+                    blend: Some(AttachmentBlend {
+                        color_op: BlendOp::Add,
+                        color_source: BlendFactor::SrcAlpha,
+                        color_destination: BlendFactor::OneMinusSrcAlpha,
+                        alpha_op: BlendOp::Max,
+                        alpha_source: BlendFactor::One,
+                        alpha_destination: BlendFactor::One,
+                    }),
+                    color_write_mask: ColorComponents::all(),
+                    color_write_enable: StateMode::Fixed(true),
+                }],
+                blend_constants: StateMode::Fixed([1.0, 1.0, 1.0, 1.0]),
+            })
+            .depth_stencil_state(DepthStencilState {
+                depth: Some(DepthState {
+                    compare_op: StateMode::Fixed(CompareOp::LessOrEqual),
+                    ..Default::default()
+                }),
+                ..DepthStencilState::simple_depth_test()
+            })
+            .render_pass(Subpass::from(render_pass, 0).unwrap())
+            .build(device.clone())
+            .unwrap();
 
         let sampler = Sampler::new(
             device,
@@ -447,7 +465,7 @@ impl Renderer {
             .unwrap()
             .add_sampled_image(texture, self.sampler.clone())
             .unwrap();
-        let descriptor_set = Arc::new(set_builder.build().unwrap());
+        let descriptor_set = set_builder.build().unwrap();
 
         (primitive_fut, vertex_fut, index_fut, descriptor_set, vertex_buffer, index_buffer)
     }
